<template>
  <el-dialog
    v-diadrag
    width="60%"
    title="同步"
    top="5vh"
    :visible.sync="innerVisible"
    append-to-body
    @close="$emit('update:currshowlist', false)"
    :show="currshowlist"
    class="part-dialog"
    id="part-dialog"
  >
    <customerorderTtable
      :table="table"
      @handleSelectionChange="handleSelectionChange"
      @currentChange="handleCurrentChange"
      :uploadInfo="uploadInfo"
      :prelang="prelang"
      :options="options"
      :bottomOffset="350"
      :ajaxFun="ajaxFun"
      :paramObj="paramObj"
      :paramArr="type"
      :selCol="'otcLineNo'"
      :selColValArr="selectedLineNos"
      :disabledVals="selColValDisabled"
      ref="commonPartTable"
    >
      <template #toolbar></template>
    </customerorderTtable>

    <div slot="footer" class="dialog-footer">
      <el-button @click="innerVisible = false">取 消</el-button>
      <el-button type="primary" @click="saveSelectRow">确 定</el-button>
    </div>
  </el-dialog>
</template>
<script>
import {
  fetchListCustomerOrder,
  processConfigMapping,
  fileAssociatedOrder,
  markPlanned
} from '@/api/plan/customerorder'
import customerorderTtable from '@/views/plan/customerorder/customerorder-ztt-table'
import { remote } from '@/api/admin/dict'

export default {
  props: {
    currshowlist: {
      type: Boolean,
      default: false
    },
    paramObj: {
      type: Object,
      default: () => {
        return {}
      }
    },
    multiSelect: {
      type: Boolean,
      default: true
    },
    parentSelectedObj: {
      type: Object,
      default: null
    },
    parentSelectedIndex: {
      type: Number,
      default: null
    }
  },
  data() {
    return {
      type: [1],
      selColValDisabled: [],
      ajaxFun: fetchListCustomerOrder,
      innerVisible: false,
      listLoading: true,
      currentRow: null,
      multipleSelection: [],
      selectedLineNos: [],
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isRefresh: false, // 是否显示刷新按钮
        isShowHide: false, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'id', direction: 'desc' },
        cancelRunCreated: true
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          {
            minWidth: '100',
            width: '150px',
            prop: 'customerOrderNo',
            label: '订单号',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            prop: 'otcLineNo',
            label: 'OTC行号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 状态
          // {
          //   minWidth: '120',
          //   prop: 'otcPartSync',
          //   label: 'OTC推送状态',
          //   sort: true,
          //   isTrue: true,
          //   isSearch: true,
          //   searchInfoType: 'select',
          //   optList: () => {
          //     return this.getOtcPartSyncOptionList()
          //   },
          //   formatter: (row, column, cellValue) => {
          //     var formatVal
          //     if (cellValue == null) {
          //       formatVal = ''
          //     } else if (cellValue) {
          //       formatVal = '已同步'
          //     } else {
          //       formatVal = '未同步'
          //     }
          //     return formatVal
          //   }
          // },
          {
            minWidth: '120',
            prop: 'customerNo',
            label: '客户编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            prop: 'customerName',
            label: '客户名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // {
          //   minWidth: '120',
          //   prop: 'isAudit',
          //   label: '审核状态',
          //   sort: true,
          //   isTrue: true,
          //   isSearch: true,
          //   searchInfoType: 'select',
          //   formatter: this.getIsAudit,
          //   optList: () => {
          //     return this.isAuditList
          //   }
          // },
          {
            minWidth: '120',
            prop: 'coLineNo',
            label: 'GSM行号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            prop: 'coState',
            label: '销售订单状态',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: this.getCustomerCoState,
            optList: () => {
              return this.coStateList
            }
          },
          {
            minWidth: '200',
            width: '120',
            prop: 'createTime',
            label: '创建时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange',
            formatter: this.formatDutyDate
          }
        ]
      },
      addOrUpdateVisible: false,
      materialTypeList: [],
      coStateList: [
        {
          value: '01partUnCheck',
          label: '零件待选'
        },
        {
          value: '02technologyUnCheck',
          label: '工艺文件待选'
        },
        {
          value: '03plan',
          label: '待计划'
        },
        {
          value: '04planed',
          label: '已下发'
        },
        {
          value: '05cancel',
          label: '已作废'
        },
        {
          value: '06unedit',
          label: '订单编辑'
        }
      ],
      isAuditList: [
        {
          value: '01draft',
          label: '草稿'
        },
        {
          value: '02pending',
          label: '审核中'
        },
        {
          value: '03accepted',
          label: '通过'
        },
        {
          value: '04reject',
          label: '退回'
        }
      ],
      otcPartSyncOptionList: [
        {
          value: true,
          label: '已同步'
        },
        {
          value: false,
          label: '未同步'
        }
      ]
    }
  },
  components: {
    customerorderTtable
  },
  methods: {
    initQueryParams() {
      const queryParam = []
      queryParam.push(
        Object.assign({
          prop: 'coState',
          searchInfoType: 'select',
          propVal: '01partUnCheck'
        })
      )
      this.$refs.commonPartTable.setQueryParam(queryParam)
      // this.paramObj = Object.assign(this.queryParam, this.paramObj)
      // this.getData()
    },
    getOtcPartSyncOptionList() {
      return this.otcPartSyncOptionList
    },
    getIsAudit(row, column, cellValue) {
      this.isAuditList.forEach((obj) => {
        if (obj.value === cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    },
    // 确定
    saveSelectRow() {
      const configFileId = this.parentSelectedObj.id
      const customerOrderList = []
      // 默认添加本行记录
      customerOrderList.push({
        otcLineNo: this.parentSelectedObj.lineNumber,
        customerOrderNo: this.parentSelectedObj.orderNumber
      })
      for (let i = 0; i < this.multipleSelection.length; i++) {
        customerOrderList.push({
          otcLineNo: this.multipleSelection[i].otcLineNo,
          customerOrderNo: this.multipleSelection[i].customerOrderNo
        })
      }
      // 工艺配置单关联销售订单
      fileAssociatedOrder({
        configFileId: configFileId,
        customerOrderList: customerOrderList
      }).then((response) => {
        const code = response.data.code
        if (code === 0) {
          this.$message.success('操作成功')
          this.$emit('listenToPartEvent')
        } else {
          this.$message.error('同步失败')
        }
      })

      this.innerVisible = false
    },
    handleCurrentChange(row) {
      this.currentRow = row
    },
    handleSelectionChange(val) {
      // 根据状态，禁用表头按钮
      // 筛选出选中记录的状态
      // var stateArr = val.map(function(value, index) {
      //   return value.coState
      // })
      // // 选中状态数组元素去重
      // var uniqueStateArr = []
      // for (var i = 0; i < stateArr.length; i++) {
      //   if (uniqueStateArr.indexOf(stateArr[i]) == -1) {
      //     uniqueStateArr.push(stateArr[i])
      //   }
      // }
      // // 循环自定义按钮，判断每个按钮的permitArr是否完全包含选中状态，若完全包含，则按钮亮，否则按钮灰
      // for (var i = 0; i < this.stateTagArr.length; i++) {
      //   if (
      //     uniqueStateArr.every((val) =>
      //       this.stateTagArr[i].permitArr.length <= 0
      //         ? true
      //         : this.stateTagArr[i].permitArr.includes(val)
      //     )
      //   ) {
      //     this.stateTagArr[i].disabled = false
      //   } else {
      //     this.stateTagArr[i].disabled = true
      //   }
      // }
      // 多行选中
      this.multipleSelection = val
    },
    getData() {
      this.selColValDisabled = [this.parentSelectedObj.lineNumber]
      this.selectedLineNos = []
      // 获取默认选中的数据
      processConfigMapping({ id: this.parentSelectedObj.id }).then(
        (response) => {
          const code = response.data.code
          if (code === 0) {
            const _data = response.data.data
            for (let i = 0; i < _data.length; i++) {
              this.selectedLineNos.push(_data[i].lineNumber)
            }
            if (this.$refs.commonPartTable !== undefined) {
              this.$refs.commonPartTable.getDataList()
            }
          }
        }
      )
    },
    getMaterialType(type) {
      remote(type).then((response) => {
        const code = response.data.code
        if (code === 0) {
          const _data = response.data.data
          this.materialTypeList = _data
        }
      })
    },
    getMaterialTypeType(row, column, cellValue) {
      this.materialTypeList.forEach((obj) => {
        if (obj.value == cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    },
    getCustomerCoState(row, column, cellValue) {
      this.coStateList.forEach((obj) => {
        if (obj.value === cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    },
    // 状态改变
    handleCommand(event) {
      var eventName
      if (event == '01partUnCheck') {
        eventName = '零件待选'
      } else if (event == '02technologyUnCheck') {
        eventName = '工艺文件待选'
      } else if (event == '03plan') {
        eventName = '待计划'
      } else if (event == '04planed') {
        eventName = '已下发'
      } else {
        eventName = '已作废'
      }
      if (this.multipleSelection.length > 0) {
        if (this.judgeCoState(this.multipleSelection)) {
          markPlanned(
            this.multipleSelection.map((item) => {
              return item.id
            }),
            event
          ).then((response) => {
            var data = response.data
            if (data.code == 0) {
              this.$message.success(eventName + '修改成功')
              this.getData()
            } else {
              this.$message.error(eventName + '修改失败')
            }
          })
        } else {
          this.$message.error('销售订单审核状态为作废，不可进行操作！')
        }
      } else {
        this.$message.error('请选择' + eventName + '的对象')
      }
    }
  },
  watch: {
    currshowlist() {
      this.innerVisible = this.currshowlist
      if (this.currshowlist) {
        this.$nextTick(() => {
          this.initQueryParams()
          this.getData()
        })
      }
    },
    coState: {
      handler(newValue, oldValue) {
        if (newValue) {
          this.getData()
        }
      },
      immediate: true
    }
  },
  mounted() {
    // this.getMaterialType('material_type')
    // this.initQueryParams()
  }
}
</script>
<style>
.part-dialog .el-dialog__header {
  padding: 10px 20px 10px;
}
.part-dialog .el-dialog__header .el-dialog__headerbtn {
  top: 10px;
}
.part-dialog .el-dialog__body {
  padding: 5px 20px;
}

.part-dialog .el-dialog__footer {
  padding: 5px 20px 10px;
}

.part-dialog .el-dialog__body .avue-crud__pagination {
  margin-top: 0px;
  margin-bottom: 5px;
}
</style>
